Index: svn/src/devices/Kconfig
===================================================================
--- svn.orig/src/devices/Kconfig
+++ svn/src/devices/Kconfig
@@ -21,33 +21,43 @@
 menu "Devices"
 
 config VGA_ROM_RUN
-	bool
+	bool "Run VGA Option ROMs"
 	help
-	  Execute PCI/AGP option ROMs if available. This is required to
-	  enable PCI/AGP VGA plugin cards.
+	  Execute VGA option ROMs if found. This is required to enable PCI/AGP
+	  VGA plugin cards.
 
-choice
-	prompt "Execute PCI option ROMs"
-	default PCI_OPTION_ROM_RUN_REALMODE
-	help
-	  Execute PCI/AGP option ROMs if available. You can choose to
-	  execute PCI option ROMs natively (32bit x86 system required),
-	  in an emulator (x86emu), or ignore option ROM execution.
-
-config PCI_OPTION_ROM_RUN_REALMODE
-	prompt "Run VGA ROMs"
-	bool
-	select VGA_ROM_RUN
-	help
-	  Execute PCI/AGP option ROMs if available. This is required to
-	  enable PCI/AGP VGA plugin cards.
-
-config NO_RUN
-	prompt "Do NOT run VGA ROMs"
-	bool
+config PCI_ROM_RUN
+	bool "Run non-VGA Option ROMs"
 	help
-	  Do not execute PCI/AGP option ROMs.
+	  Execute non-VGA PCI option ROMs if found.
 
+choice
+        prompt "Option ROM Execution"
+        default  PCI_OPTION_ROM_RUN_REALMODE
+	depends on PCI_ROM_RUN || VGA_ROM_RUN
+        help
+          You can choose to execute PCI option ROMs natively (32bit x86 system
+	  required) or in an emulator (x86emu or YABEL).
+
+	config PCI_OPTION_ROM_RUN_REALMODE
+		prompt "Real mode"
+		bool
+
+	config PCI_OPTION_ROM_RUN_YABEL
+		prompt "YABEL"
+		bool
+
+	config PCI_OPTION_ROM_RUN_X86EMU
+		prompt "X86EMU"
+		bool
 endchoice
 
+config YABEL_DEBUG_FLAGS
+	prompt "Hex value for debug flags"
+	hex
+	default 0x0
+	depends on PCI_OPTION_ROM_RUN_YABEL
+	help
+	  See debug.h for values 0 is no debug output, 0x31ff is _verbose_.
+
 endmenu
Index: svn/src/devices/Makefile.inc
===================================================================
--- svn.orig/src/devices/Makefile.inc
+++ svn/src/devices/Makefile.inc
@@ -12,8 +12,8 @@ obj-y += pci_ops.o
 obj-y += smbus_ops.o
 
 ifeq ($(CONFIG_PCI_ROM_RUN),y)
-obj-$(CONFIG_PCI_ROM_RUN) += pci_rom.o
-subdirs-$(CONFIG_PCI_ROM_RUN) += ../../util/x86emu
+obj-y += pci_rom.o
+subdirs-y += ../../util/x86emu
 else
 obj-$(CONFIG_VGA_ROM_RUN) += pci_rom.o
 subdirs-$(CONFIG_VGA_ROM_RUN) += ../../util/x86emu
Index: svn/util/x86emu/Makefile.inc
===================================================================
--- svn.orig/util/x86emu/Makefile.inc
+++ svn/util/x86emu/Makefile.inc
@@ -19,9 +19,12 @@
 ##
 
 subdirs-$(CONFIG_PCI_OPTION_ROM_RUN_X86EMU) += x86emu
-obj-$(CONFIG_PCI_OPTION_ROM_RUN_X86EMU) += biosemu.c
+obj-$(CONFIG_PCI_OPTION_ROM_RUN_X86EMU) += biosemu.o
 subdirs-$(CONFIG_PCI_OPTION_ROM_RUN_X86EMU) += pcbios
 
 obj-$(CONFIG_PCI_OPTION_ROM_RUN_REALMODE) += x86.o
 obj-$(CONFIG_PCI_OPTION_ROM_RUN_REALMODE) += x86_asm.o
 obj-$(CONFIG_PCI_OPTION_ROM_RUN_REALMODE) += x86_interrupts.o
+
+subdirs-$(CONFIG_PCI_OPTION_ROM_RUN_YABEL) += x86emu
+subdirs-$(CONFIG_PCI_OPTION_ROM_RUN_YABEL) += yabel
Index: svn/util/x86emu/yabel/compat/Makefile.inc
===================================================================
--- /dev/null
+++ svn/util/x86emu/yabel/compat/Makefile.inc
@@ -0,0 +1 @@
+obj-y += functions.o
Index: svn/util/x86emu/yabel/Makefile.inc
===================================================================
--- /dev/null
+++ svn/util/x86emu/yabel/Makefile.inc
@@ -0,0 +1,8 @@
+obj-y += biosemu.o
+obj-y += debug.o
+obj-y += device.o
+obj-y += interrupt.o
+obj-y += io.o
+obj-y += mem.o
+obj-y += pmm.o
+subdirs-y += compat
Index: svn/Makefile
===================================================================
--- svn.orig/Makefile
+++ svn/Makefile
@@ -215,6 +215,7 @@ printall:
 OBJS     := $(patsubst %,$(obj)/%,$(TARGETS-y))
 INCLUDES := -I$(top)/src -I$(top)/src/include -I$(obj) -I$(top)/src/arch/$(ARCHDIR-y)/include 
 INCLUDES += -I$(shell $(CC) -print-search-dirs | head -n 1 | cut -d' ' -f2)include
+INCLUDES += -I$(top)/util/x86emu/include
 INCLUDES += -include $(obj)/build.h
 
 try-run= $(shell set -e; \
Index: svn/util/x86emu/yabel/biosemu.c
===================================================================
--- svn.orig/util/x86emu/yabel/biosemu.c
+++ svn/util/x86emu/yabel/biosemu.c
@@ -56,8 +56,6 @@ static X86EMU_pioFuncs my_pio_funcs = {
 /* interrupt function override array (see biosemu.h) */
 yabel_handleIntFunc yabel_intFuncArray[256];
 
-void dump(u8 * addr, u32 len);
-
 /* main entry into YABEL biosemu, arguments are:
  * *biosmem = pointer to virtual memory
  * biosmem_size = size of the virtual memory
